.. drf-spectacular documentation master file, created by
   sphinx-quickstart on Sun Mar  1 22:11:53 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

drf-spectacular
===============

  `Sane and flexible OpenAPI 3 schema generation for Django REST framework.`

Documentation is an integral part of API development and OpenAPI 3 is finally here
to make that process a easier. By using `drf-spectacular <https://github.com/tfranzel/drf-spectacular>`_
with `Django REST Framework (DRF) <https://www.django-rest-framework.org/">`_,
your schema and therefore your documentation & client will always stay close to your API.

drf-spectacular works well out of the box, but also provides you with several easy ways
to customize the generated OpenAPI 3 schema. It is explicitly designed to work well for
documentation (`SwaggerUI <https://swagger.io/tools/swagger-ui>`_, `ReDoc <https://github.com/Redocly/redoc>`_)
and automatic `client generation <https://openapi-generator.tech>`_.

Table of Contents
-----------------

.. toctree::
   :maxdepth: 3

   readme.rst
   settings.rst
   customization.rst
   client_generation.rst
   faq.rst
   blueprints.rst
   drf_yasg.rst
   license.rst
   changelog.rst
   drf_spectacular.rst


Indices and Tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
